Class BuffersUtils

    • Constructor Summary

      Constructors 
      Constructor Description
      BuffersUtils()  
    • Method Summary

      All Methods Static Methods Concrete Methods 
      Modifier and Type Method Description
      static int append​(ByteBuffer src, io.undertow.connector.PooledByteBuffer[] dest, io.undertow.server.HttpServerExchange exchange)
      append the src data to the pooled buffers
      static void dump​(String msg, io.undertow.connector.PooledByteBuffer[] data)  
      static byte[] getByteArray​(io.undertow.connector.PooledByteBuffer[] src)
      Returns the actual byte array of the PooledByteBuffer
      static byte[] toByteArray​(io.undertow.connector.PooledByteBuffer[] src)  
      static ByteBuffer toByteBuffer​(io.undertow.connector.PooledByteBuffer[] srcs)  
      static String toString​(byte[] src, Charset cs)  
      static String toString​(io.undertow.connector.PooledByteBuffer[] srcs, String charsetName)  
      static String toString​(io.undertow.connector.PooledByteBuffer[] srcs, Charset cs)  
      static int transfer​(io.undertow.connector.PooledByteBuffer[] src, io.undertow.connector.PooledByteBuffer[] dest, io.undertow.server.HttpServerExchange exchange)  
      static int transfer​(ByteBuffer src, io.undertow.connector.PooledByteBuffer[] dest, io.undertow.server.HttpServerExchange exchange)
      transfer the src data to the pooled buffers overwriting the exising data
    • Field Detail

      • MAX_CONTENT_SIZE

        public static final int MAX_CONTENT_SIZE
    • Constructor Detail

      • BuffersUtils

        public BuffersUtils()
    • Method Detail

      • toByteBuffer

        public static ByteBuffer toByteBuffer​(io.undertow.connector.PooledByteBuffer[] srcs)
                                       throws IOException
        Parameters:
        srcs - PooledByteBuffer[]
        Returns:
        a ByteBuffer containing the content of the srcs
        Throws:
        IOException - If the content exceeds the MAX_CONTENT_SIZE
      • toByteArray

        public static byte[] toByteArray​(io.undertow.connector.PooledByteBuffer[] src)
                                  throws IOException
        Throws:
        IOException
      • getByteArray

        public static byte[] getByteArray​(io.undertow.connector.PooledByteBuffer[] src)
                                   throws IOException
        Returns the actual byte array of the PooledByteBuffer
        Parameters:
        src -
        Returns:
        Throws:
        IOException
      • transfer

        public static int transfer​(ByteBuffer src,
                                   io.undertow.connector.PooledByteBuffer[] dest,
                                   io.undertow.server.HttpServerExchange exchange)
        transfer the src data to the pooled buffers overwriting the exising data
        Parameters:
        src - ByteBuffer
        dest - PooledByteBuffer[]
        exchange - HttpServerExchange
        Returns:
        int
      • dump

        public static void dump​(String msg,
                                io.undertow.connector.PooledByteBuffer[] data)
      • append

        public static int append​(ByteBuffer src,
                                 io.undertow.connector.PooledByteBuffer[] dest,
                                 io.undertow.server.HttpServerExchange exchange)
        append the src data to the pooled buffers
        Parameters:
        src - ByteBuffer
        dest - PooledByteBuffer[]
        exchange - HttpServerExchange
        Returns:
        int
      • transfer

        public static int transfer​(io.undertow.connector.PooledByteBuffer[] src,
                                   io.undertow.connector.PooledByteBuffer[] dest,
                                   io.undertow.server.HttpServerExchange exchange)