Package com.networknt.handler
Interface RequestInterceptor
-
- All Superinterfaces:
io.undertow.server.HttpHandler,Interceptor,LightHttpHandler,MiddlewareHandler
public interface RequestInterceptor extends Interceptor
This is the interface for the request interceptors. It is just a normal middleware handler with some extra indicators.
-
-
Field Summary
-
Fields inherited from interface com.networknt.handler.Interceptor
CONTENT_TYPE_MISMATCH, JSON_ARRAY_OBJECT_STARTING_CHAR, JSON_MAP_OBJECT_STARTING_CHAR
-
Fields inherited from interface com.networknt.handler.LightHttpHandler
AUDIT_CONFIG_NAME, AUDIT_ON_ERROR, AUDIT_STACK_TRACE, auditConfig, auditOnError, auditStackTrace, config, CONFIG_NAME, ERROR_NOT_DEFINED, logger
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description booleanisRequiredContent()-
Methods inherited from interface com.networknt.handler.Interceptor
findMatchingPrefix, isFormData, isJsonData, isXmlData, parseJsonArrayObject, parseJsonMapObject, shouldAttachBody
-
Methods inherited from interface com.networknt.handler.LightHttpHandler
setExchangeStatus, setExchangeStatus, setExchangeStatus
-
Methods inherited from interface com.networknt.handler.MiddlewareHandler
addHandlerMDCContext, getNext, isEnabled, register, reload, setNext
-
-