Class RequestInterceptorInjectionHandler

  • All Implemented Interfaces:
    LightHttpHandler, MiddlewareHandler, io.undertow.server.HttpHandler

    public class RequestInterceptorInjectionHandler
    extends Object
    implements MiddlewareHandler
    This is the middleware used in the request/response chain to inject the implementations of RequestInterceptorHandler interface to modify the request metadata and body. You can have multiple interceptors per application; however, we do provide a generic implementation in request-transform module to transform the request based on the rule engine rules.
    Author:
    Kalev Gonvick
    • Constructor Detail

      • RequestInterceptorInjectionHandler

        public RequestInterceptorInjectionHandler()
      • RequestInterceptorInjectionHandler

        public RequestInterceptorInjectionHandler​(RequestInjectionConfig cfg)
    • Method Detail

      • getNext

        public io.undertow.server.HttpHandler getNext()
        Description copied from interface: MiddlewareHandler
        Get the next handler in the chain
        Specified by:
        getNext in interface MiddlewareHandler
        Returns:
        HttpHandler
      • isEnabled

        public boolean isEnabled()
        Description copied from interface: MiddlewareHandler
        Indicate if this handler is enabled or not.
        Specified by:
        isEnabled in interface MiddlewareHandler
        Returns:
        boolean true if enabled
      • reload

        public void reload()
        Description copied from interface: MiddlewareHandler
        Reload config values in case the config values changed by config server.
        Specified by:
        reload in interface MiddlewareHandler
      • handleRequest

        public void handleRequest​(io.undertow.server.HttpServerExchange httpServerExchange)
                           throws Exception
        Specified by:
        handleRequest in interface io.undertow.server.HttpHandler
        Throws:
        Exception