Package com.networknt.handler
Class ResponseInjectionConfig
- java.lang.Object
-
- com.networknt.handler.ResponseInjectionConfig
-
public class ResponseInjectionConfig extends Object
The config class for the ResponseInterceptorInjectionHandler middleware handler.
-
-
Field Summary
Fields Modifier and Type Field Description static StringCONFIG_NAME
-
Constructor Summary
Constructors Constructor Description ResponseInjectionConfig()ResponseInjectionConfig(String configName)Please note that this constructor is only for testing to load different config files to test different configurations.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description List<String>getAppliedBodyInjectionPathPrefixes()booleanisEnabled()
-
-
-
Field Detail
-
CONFIG_NAME
public static final String CONFIG_NAME
- See Also:
- Constant Field Values
-
-
Constructor Detail
-
ResponseInjectionConfig
public ResponseInjectionConfig()
-
ResponseInjectionConfig
public ResponseInjectionConfig(String configName)
Please note that this constructor is only for testing to load different config files to test different configurations.- Parameters:
configName- String
-
-