Uses of Interface
com.networknt.handler.LightHttpHandler
-
Packages that use LightHttpHandler Package Description com.networknt.handler -
-
Uses of LightHttpHandler in com.networknt.handler
Subinterfaces of LightHttpHandler in com.networknt.handler Modifier and Type Interface Description interfaceInterceptorinterfaceMiddlewareHandlerA interface for middleware handlers.interfaceRequestInterceptorThis is the interface for the request interceptors.interfaceResponseInterceptorThis handler is special middleware handler, and it is used to inject response interceptors in the request/response chain to modify/transform the response before calling the next middleware handler.Classes in com.networknt.handler that implement LightHttpHandler Modifier and Type Class Description classOrchestrationHandlerclassRequestInterceptorInjectionHandlerThis is the middleware used in the request/response chain to inject the implementations of RequestInterceptorHandler interface to modify the request metadata and body.classResponseInterceptorInjectionHandlerThis is a middleware handle that is responsible for injecting the SinkConduit in order to update the response content for interceptor handlers to update the response before returning to client.
-