Package com.networknt.handler.config
Interface EndpointSource
-
public interface EndpointSourceInterface for generating a sequence of path/method pairs for injecting into handler.yml
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static classEndpointSource.Endpoint
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description Iterable<EndpointSource.Endpoint>listEndpoints()
-
-
-
Method Detail
-
listEndpoints
Iterable<EndpointSource.Endpoint> listEndpoints()
-
-