Package com.networknt.handler
package com.networknt.handler
-
ClassDescriptionA user handler provider interface.This is an extension of HttpHandler that provides a default method to handle error status.A interface for middleware handlers.This is the interface for the request interceptors.This is the middleware used in the request/response chain to inject the implementations of RequestInterceptorHandler interface to modify the request metadata and body.The config class for the ResponseInterceptorInjectionHandler middleware handler.This handler is special middleware handler, and it is used to inject response interceptors in the request/response chain to modify/transform the response before calling the next middleware handler.This is a middleware handle that is responsible for injecting the SinkConduit in order to update the response content for interceptor handlers to update the response before returning to client.