Constant Field Values
Contents
com.networknt.*
-
com.networknt.handler.BuffersUtils Modifier and Type Constant Field Value public static final intMAX_CONTENT_SIZE16777216 -
com.networknt.handler.LightHttpHandler Modifier and Type Constant Field Value public static final StringAUDIT_CONFIG_NAME"audit"public static final StringAUDIT_ON_ERROR"auditOnError"public static final StringAUDIT_STACK_TRACE"auditStackTrace"public static final StringCONFIG_NAME"handler"public static final StringERROR_NOT_DEFINED"ERR10042" -
com.networknt.handler.RequestInjectionConfig Modifier and Type Constant Field Value public static final StringCONFIG_NAME"request-injection" -
com.networknt.handler.RequestInterceptorInjectionHandler Modifier and Type Constant Field Value public static final intMAX_BUFFERS1024 -
com.networknt.handler.ResponseInjectionConfig Modifier and Type Constant Field Value public static final StringCONFIG_NAME"response-injection"