Interface HandlerProvider


  • public interface HandlerProvider
    A user handler provider interface. The framework has some middleware handlers and these are wired into the request/response chain at the right sequence. At the end of the request chain, the user business logic need to be called to do the real processing and it is usually implemented as a serial of handlers. These handlers needs to be grouped together and mapped to certain URLs and http methods. The mapping class implements this HandlerProvider so that it can be loaded during server startup to inject into the handler chain.
    Author:
    Steve Hu
    • Method Summary

      All Methods Instance Methods Abstract Methods 
      Modifier and Type Method Description
      io.undertow.server.HttpHandler getHandler()
      Every handler provider needs to implement this method to return a HttpHanlder or a chain of HttpHandlers.
    • Method Detail

      • getHandler

        io.undertow.server.HttpHandler getHandler()
        Every handler provider needs to implement this method to return a HttpHanlder or a chain of HttpHandlers.
        Returns:
        HttpHandler