Interface ResponseInterceptor

  • All Superinterfaces:
    io.undertow.server.HttpHandler, Interceptor, LightHttpHandler, MiddlewareHandler

    public interface ResponseInterceptor
    extends Interceptor
    This handler is special middleware handler, and it is used to inject response interceptors in the request/response chain to modify/transform the response before calling the next middleware handler.