Package com.networknt.handler
-
Interface Summary Interface Description HandlerProvider A user handler provider interface.Interceptor LightHttpHandler This is an extension of HttpHandler that provides a default method to handle error status.MiddlewareHandler A interface for middleware handlers.RequestInterceptor This is the interface for the request interceptors.ResponseInterceptor This handler is special middleware handler, and it is used to inject response interceptors in the request/response chain to modify/transform the response before calling the next middleware handler. -
Class Summary Class Description AuditAttachmentUtil BuffersUtils Handler OrchestrationHandler RequestInjectionConfig RequestInterceptorInjectionHandler This is the middleware used in the request/response chain to inject the implementations of RequestInterceptorHandler interface to modify the request metadata and body.ResponseInjectionConfig The config class for the ResponseInterceptorInjectionHandler middleware handler.ResponseInterceptorInjectionHandler This is a middleware handle that is responsible for injecting the SinkConduit in order to update the response content for interceptor handlers to update the response before returning to client.